import torch
import torch.nn as nn

class IntentClassifier(nn.Module):
    def __init__(self, input_dim=300, hidden_dims=[128, 64], num_classes=4, dropout=0.3):
        super().__init__()
        layers = []
        prev_dim = input_dim
        for h in hidden_dims:
            layers.append(nn.Linear(prev_dim, h))
            layers.append(nn.ReLU())
            layers.append(nn.Dropout(dropout))
            prev_dim = h
        layers.append(nn.Linear(prev_dim, num_classes))
        self.fc = nn.Sequential(*layers)

    def forward(self, x):
        return self.fc(x)


from setuptools import setup, find_packages
import os

# Read the contents of your README file
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="uni9ja-intent",
    version="0.1.4",
    author="Godsave O. Kawurem",
    author_email="godsaveogbidor@gmail.com",
    description="A lightweight Nigerian-focused intent classifier using SpaCy and PyTorch",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Perfect-Aimers-Enterprise/uni9ja_nlp.git",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',
    install_requires=[
        "torch",
        "spacy",
        "scikit-learn",
    ],
)


import json
import os

def load_data(file_path: str):
    """
    Accepts .json or .jsonl
    Returns a list of dicts: [{"text":..., "label":...}, ...]
    """
    data = []

    if not os.path.exists(file_path):
        raise FileNotFoundError(f"No file found at {file_path}")

    if file_path.endswith(".json"):
        with open(file_path, "r", encoding="utf-8") as f:
            data = json.load(f)
            if not isinstance(data, list):
                raise ValueError("JSON must be an array of objects")
    elif file_path.endswith(".jsonl"):
        with open(file_path, "r", encoding="utf-8") as f:
            for line in f:
                line = line.strip()
                if line:
                    try:
                        obj = json.loads(line)
                        data.append(obj)
                    except json.JSONDecodeError as e:
                        print(f"Skipping invalid line: {line}\nError: {e}")
    else:
        raise ValueError("File must be .json or .jsonl")

    # Validate structure
    for item in data:
        if "text" not in item or "label" not in item:
            raise ValueError("Each object must have 'text' and 'label'")

    return data